
// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "TeeTest.h"

#include "MainFrm.h"

#include "TeeChart\TeeChartDefines.h"
#include "TeeChart\brush.h"
#include "TeeChart\canvas.h"
#include "TeeChart\series.h"
#include "TeeChart\barseries.h"
#include "TeeChart\zoom.h"
#include "TeeChart\scroll.h"
#include "TeeChart\environment.h"
#include "TeeChart\aspect.h"
#include "TeeChart\teegdiplus.h"
#include "TeeChart\marks.h"
#include "TeeChart\teefont.h"
#include "TeeChart\pen.h"
#include "TeeChart\teeshadow.h"
#include "TeeChart\axes.h"
#include "TeeChart\axis.h"
#include "TeeChart\axislabels.h"

#define ID_CHART1		1000

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

// CMainFrame

IMPLEMENT_DYNAMIC(CMainFrame, CFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
	ON_WM_CREATE()
	ON_WM_DESTROY()
	ON_WM_SIZE()
	ON_WM_TIMER()
END_MESSAGE_MAP()

BEGIN_EVENTSINK_MAP(CMainFrame, CFrameWnd)
	ON_EVENT(CMainFrame, ID_CHART1, 1, OnAfterDrawTchart, VTS_NONE)
	ON_EVENT(CMainFrame, ID_CHART1, 19, OnMouseDownTchart, VTS_I4 VTS_I4 VTS_I4 VTS_I4)
	ON_EVENT(CMainFrame, ID_CHART1, 20, OnMouseMoveTchart, VTS_I4 VTS_I4 VTS_I4)
	ON_EVENT(CMainFrame, ID_CHART1, 21, OnMouseUpTchart, VTS_I4 VTS_I4 VTS_I4 VTS_I4)
END_EVENTSINK_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};

// CMainFrame construction/destruction

CMainFrame::CMainFrame()
	: m_offset(0)
	, m_bDragging(false)
	, series(-1)
{
}

CMainFrame::~CMainFrame()
{
}

int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	Gdiplus::GdiplusStartupInput gdiPlusStartupInput;
	Gdiplus::GdiplusStartup(&m_GdiPlusToken, &gdiPlusStartupInput, NULL);

	if (CFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;

    CRect rect;
    GetClientRect(rect);

	CRect chart1Rect(rect);

	m_pChart1 = std::unique_ptr<CTChart>(new CTChart());
    if (!m_pChart1->Create("Chart 1", WS_CHILD|WS_VISIBLE, chart1Rect, this, ID_CHART1))
		return -1;
	m_pChart1->GetAspect().GetGDIPlus().SetActive(false);
	m_pChart1->GetAspect().SetView3D(false);

	if (!m_wndStatusBar.Create(this))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}
	m_wndStatusBar.SetIndicators(indicators, sizeof(indicators)/sizeof(UINT));

	SetTimer(1, 1000, NULL);

	return 0;
}

afx_msg void CMainFrame::OnDestroy()
{
	KillTimer(1);

	Gdiplus::GdiplusShutdown(m_GdiPlusToken);
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CFrameWnd::PreCreateWindow(cs) )
		return FALSE;
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	cs.dwExStyle &= ~WS_EX_CLIENTEDGE;
	cs.lpszClass = AfxRegisterWndClass(0);
	return TRUE;
}

// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CFrameWnd::Dump(dc);
}
#endif //_DEBUG


// CMainFrame message handlers

void CMainFrame::OnAfterDrawTchart()
{
	// called by chart to do custom drawing after chart has been painted

	// nothing to do if chart has not been created
	if (m_pChart1->GetSafeHwnd() == NULL)
	{
		ASSERT(false);
		return;
	}

	// get canvas
	CCanvas& canvas = m_pChart1->GetCanvas();

	// prepare pen
	if (m_offset == 0)
	{
		canvas.GetPen().SetStyle(psSolid);
	}
	else
	{
		canvas.GetPen().SetStyle(psDot);
	}

	if (m_bDragging == false)
	{
		canvas.GetPen().SetColor(RGB(0,0,0));
	}
	else
	{
		canvas.GetPen().SetColor(RGB(255,0,0));
	}
	//canvas.SetBackMode(cbmTransparent);

	// prepare brush; sets ICanvas.BackMode to cbmTransparent
	canvas.GetBrush().SetStyle(bsClear);

	// draw rectangle
	canvas.Rectangle(200 + m_offset, 200 + m_offset, 300 + m_offset, 300 + m_offset);
}

void CMainFrame::OnMouseDownTchart(long Button, long Shift, long X, long Y)
{
	// nothing to do if chart has not been created
	if (m_pChart1->GetSafeHwnd() == NULL)
	{
		ASSERT(false);
		return;
	}

	if (Button == mbLeft && m_bDragging == false)
	{
		//m_offset = 0;
		m_bDragging = true;
		if (series != -1)
		{
			m_pChart1->RemoveSeries(series);
			series = -1;
		}

		if (series == -1)
		{
			series = m_pChart1->AddSeries(scBar);
			CSeries& s = m_pChart1->Series(series);
			s.FillSampleValues(10);
		}
		//m_pChart1->GetEnvironment().InternalRepaint();
		//m_pChart1->Invalidate();
	}
}

void CMainFrame::OnMouseMoveTchart(long Shift, long X, long Y)
{
	// nothing to do if chart has not been created
	if (m_pChart1->GetSafeHwnd() == NULL)
	{
		ASSERT(false);
		return;
	}

	if (m_bDragging == true)
	{
		//if (m_offset == 0)
		//{
		//	m_offset = 25;
		//}
		//else
		//{
		//	m_offset = 0;
		//}
		//m_pChart1->GetEnvironment().InternalRepaint();
		//m_pChart1->Invalidate();
	}
}

void CMainFrame::OnMouseUpTchart(long Button, long Shift, long X, long Y)
{
	// nothing to do if chart has not been created
	if (m_pChart1->GetSafeHwnd() == NULL)
	{
		ASSERT(false);
		return;
	}

	if (Button == mbLeft && m_bDragging == true)
	{
		//m_offset = 0;
		m_bDragging = false;
		//m_pChart1->GetEnvironment().InternalRepaint();
		//m_pChart1->Invalidate();
	}
}


void CMainFrame::OnSize(UINT nType, int cx, int cy)
{
	CFrameWnd::OnSize(nType, cx, cy);

	if (m_pChart1->GetSafeHwnd() != NULL)
	{
		m_pChart1->MoveWindow(0, 0, cx, cy);
	}
}


void CMainFrame::OnTimer(UINT_PTR nIDEvent)
{
	if (m_bDragging == false)
	{
		if (m_offset == 0)
		{
			m_offset = 25;
		}
		else
		{
			m_offset = 0;
		}

		m_pChart1->GetEnvironment().InternalRepaint();
		//m_pChart1->Invalidate();
		m_pChart1->RedrawWindow();
	}

	CFrameWnd::OnTimer(nIDEvent);
}
